==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectNature.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnature_h
#define objectnature_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_nature {
  t_adms _adms;
  char* _access;
  int _access_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  p_number _abstol;
  int _abstol_isdefault : 1;
  p_nature _base;
  int _base_isdefault : 1;
  p_nature _ddtNature;
  int _ddtNature_isdefault : 1;
  p_nature _idtNature;
  int _idtNature_isdefault : 1;
  char* _units;
  int _units_isdefault : 1;
};
#include <admsObject/objectNumber.h>
#include <admsObject/objectNature.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nature_getuid (p_nature mynature);
win32_interface gboolean adms_nature_cmp (p_nature mynature,p_nature refnature);
win32_interface p_nature adms_nature_new_1 (char* myaccess);
#define adms_nature_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_nature_free(item)\
{\
  free(item->_access);\
  free(item->_name);\
  free(item->_units);\
  free(item);\
}
win32_interface p_adms adms_nature_new_impl (p_adms arguments[]);
win32_interface p_nature adms_nature_impl (void* member);
#define adms_nature(member) ((p_nature) (member))
#define adms_nature_new adms_nature_new_1
#define adms_nature_isdefault_access(nature) (adms_nature(nature)->_access_isdefault)
#define adms_nature_valueof_access(nature) (adms_nature(nature)->_access)
#define adms_nature_isdefault_name(nature) (adms_nature(nature)->_name_isdefault)
#define adms_nature_valueof_name(nature) (adms_nature(nature)->_name)
#define adms_nature_isdefault_abstol(nature) (adms_nature(nature)->_abstol_isdefault)
#define adms_nature_valueof_abstol(nature) (adms_nature(nature)->_abstol)
#define adms_nature_isdefault_base(nature) (adms_nature(nature)->_base_isdefault)
#define adms_nature_valueof_base(nature) (adms_nature(nature)->_base)
#define adms_nature_isdefault_ddtNature(nature) (adms_nature(nature)->_ddtNature_isdefault)
#define adms_nature_valueof_ddtNature(nature) (adms_nature(nature)->_ddtNature)
#define adms_nature_isdefault_idtNature(nature) (adms_nature(nature)->_idtNature_isdefault)
#define adms_nature_valueof_idtNature(nature) (adms_nature(nature)->_idtNature)
#define adms_nature_isdefault_units(nature) (adms_nature(nature)->_units_isdefault)
#define adms_nature_valueof_units(nature) (adms_nature(nature)->_units)
#define adms_nature_valueof_adms(nature) ((p_adms)nature)
#define adms_nature_valueto_access(a,b) ((p_nature)a)->_access=(b)
win32_interface void adms_nature_valueto_access_impl (p_nature mynature,char* _access);
#define adms_nature_valueto_name(a,b) ((p_nature)a)->_name=(b)
win32_interface void adms_nature_valueto_name_impl (p_nature mynature,char* _name);
#define adms_nature_valueto_abstol(a,b) ((p_nature)a)->_abstol=(b)
win32_interface void adms_nature_valueto_abstol_impl (p_nature mynature,p_number _abstol);
#define adms_nature_valueto_base(a,b) ((p_nature)a)->_base=(b)
win32_interface void adms_nature_valueto_base_impl (p_nature mynature,p_nature _base);
#define adms_nature_valueto_ddtNature(a,b) ((p_nature)a)->_ddtNature=(b)
win32_interface void adms_nature_valueto_ddtNature_impl (p_nature mynature,p_nature _ddtNature);
#define adms_nature_valueto_idtNature(a,b) ((p_nature)a)->_idtNature=(b)
win32_interface void adms_nature_valueto_idtNature_impl (p_nature mynature,p_nature _idtNature);
#define adms_nature_valueto_units(a,b) ((p_nature)a)->_units=(b)
win32_interface void adms_nature_valueto_units_impl (p_nature mynature,char* _units);
#endif /* objectnature_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectNature.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnature_h
#define objectnature_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_nature {
  t_adms _adms;
  p_quark _access;
  int _access_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_number _abstol;
  int _abstol_isdefault : 1;
  p_nature _base;
  int _base_isdefault : 1;
  p_nature _ddtNature;
  int _ddtNature_isdefault : 1;
  p_nature _idtNature;
  int _idtNature_isdefault : 1;
  p_quark _units;
  int _units_isdefault : 1;
};
#include <admsObject/objectQuark.h>
#include <admsObject/objectNumber.h>
#include <admsObject/objectNature.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nature_uid (p_nature mynature);
win32_interface int adms_nature_cmp (p_nature mynature,p_nature refnature);
win32_interface p_nature adms_nature_new(p_quark myaccess);
win32_interface p_adms adms_nature_new_impl (p_adms arguments[]);
#define adms_nature(member) ((p_nature) (member))
#define adms_nature_isdefault_access(nature) (adms_nature(nature)->_access_isdefault)
#define adms_nature_valueof_access(nature) (adms_nature(nature)->_access)
#define adms_nature_isdefault_name(nature) (adms_nature(nature)->_name_isdefault)
#define adms_nature_valueof_name(nature) (adms_nature(nature)->_name)
#define adms_nature_isdefault_abstol(nature) (adms_nature(nature)->_abstol_isdefault)
#define adms_nature_valueof_abstol(nature) (adms_nature(nature)->_abstol)
#define adms_nature_isdefault_base(nature) (adms_nature(nature)->_base_isdefault)
#define adms_nature_valueof_base(nature) (adms_nature(nature)->_base)
#define adms_nature_isdefault_ddtNature(nature) (adms_nature(nature)->_ddtNature_isdefault)
#define adms_nature_valueof_ddtNature(nature) (adms_nature(nature)->_ddtNature)
#define adms_nature_isdefault_idtNature(nature) (adms_nature(nature)->_idtNature_isdefault)
#define adms_nature_valueof_idtNature(nature) (adms_nature(nature)->_idtNature)
#define adms_nature_isdefault_units(nature) (adms_nature(nature)->_units_isdefault)
#define adms_nature_valueof_units(nature) (adms_nature(nature)->_units)
#define adms_nature_valueof_adms(nature) ((p_adms)nature)
win32_interface inline void adms_nature_valueto_access (p_nature mynature,p_quark _access);
win32_interface inline void adms_nature_valueto_name (p_nature mynature,p_quark _name);
win32_interface inline void adms_nature_valueto_abstol (p_nature mynature,p_number _abstol);
win32_interface inline void adms_nature_valueto_base (p_nature mynature,p_nature _base);
win32_interface inline void adms_nature_valueto_ddtNature (p_nature mynature,p_nature _ddtNature);
win32_interface inline void adms_nature_valueto_idtNature (p_nature mynature,p_nature _idtNature);
win32_interface inline void adms_nature_valueto_units (p_nature mynature,p_quark _units);
win32_interface inline void adms_nature_free(p_nature mynature);
#endif /* objectnature_h */
